# Changelog

## 0.1.1 (2026-02-26)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/reduce/vibedropper-python/compare/v0.1.0...v0.1.1)

### Chores

* update SDK settings ([9557854](https://github.com/reduce/vibedropper-python/commit/9557854444d9ebf7985553fe56d0ea54b1d993df))
* update SDK settings ([91819a0](https://github.com/reduce/vibedropper-python/commit/91819a0da30defb2e20dbfbf8ccd59c32e60c1a6))

## 0.1.0 (2026-02-26)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/reduce/vibedropper-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([0eb8a24](https://github.com/reduce/vibedropper-python/commit/0eb8a244135eb2145cda9a04f5b4e31bb4f2391c))


### Chores

* **internal:** add request options to SSE classes ([ba06a2a](https://github.com/reduce/vibedropper-python/commit/ba06a2ac5ba09fb6a34a4cb123f459791cd27492))
* **internal:** make `test_proxy_environment_variables` more resilient ([bd5fdc6](https://github.com/reduce/vibedropper-python/commit/bd5fdc6213f5858b337c17627347f0636c996aa1))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([3b7ffb5](https://github.com/reduce/vibedropper-python/commit/3b7ffb581b1518ab7ccae69c8dd3ccdaf434fd76))
* sync repo ([2c0efa5](https://github.com/reduce/vibedropper-python/commit/2c0efa518e8ab5e51f579eda1c818969664158e3))
* update SDK settings ([9685d64](https://github.com/reduce/vibedropper-python/commit/9685d644bab31cc8bfccc7d894b10cb6e61bc8fc))
* update SDK settings ([77b4ed2](https://github.com/reduce/vibedropper-python/commit/77b4ed28aa4de1ae72dac8588a5cf31427cc6e54))
* update SDK settings ([71a6451](https://github.com/reduce/vibedropper-python/commit/71a6451366bbaba9d7c0aae14a7b0352c43a24e4))
* update SDK settings ([9042609](https://github.com/reduce/vibedropper-python/commit/9042609e96146714c7e892679471178de9053e8d))
* update SDK settings ([bc06c78](https://github.com/reduce/vibedropper-python/commit/bc06c780fdbc7ba0daeaf518569496104badca63))
* update SDK settings ([66f46c5](https://github.com/reduce/vibedropper-python/commit/66f46c58d9226c67b34a4b807f8770d7dbe1ad2e))
